#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.reference import Reference
from pycatia.structure_interfaces.str_foundation import StrFoundation
from pycatia.structure_interfaces.str_member import StrMember
from pycatia.structure_interfaces.str_plate import StrPlate
from pycatia.structure_interfaces.str_section import StrSection
from pycatia.system_interfaces.any_object import AnyObject


class StrObjectFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrObjectFactory
                | 
                | Represents the factory object for all the structure objects.
                | The factory is retrieved using the Product.GetTechnologicalObject method of the
                | product.
                | 
                | Example:
                |     The following example retrieves the structure factory object from the
                |     oProduct Product.
                | 
                |      Dim oFactory as AnyObject
                |      Set oFactory = oProduct.GetTechnologicalObject("StructureObjectFactory")
                |      
                | 
                |     Method Index
                |     AddDefExtFromCoordinates
                |         Creates a member extremity definition object from coordinates and an
                |         offset value. 
                |     AddDefExtFromReference
                |         Creates a member extremity definition object from an existing object in
                |         the model and an offset value. 
                |     AddDefExtOnMember
                |         Creates a member extremity definition object from another member
                |         object, its side, a distance on it and an offset. 
                |     AddDimMember
                |         Creates a dimension member object from a point and a mathematical
                |         definition of a direction. 
                |     AddDimMemberOnPlane
                |         Creates a dimension member object on a plane following a mathematical
                |         definition of a plane. 
                |     AddDimMemberPtPt
                |         Creates a dimension member object from two given points.
                |         
                |     AddDimMemberWithSupport
                |         Creates a dimension member object using a support object.
                |         
                |     AddMember
                |         Creates a member object. 
                |     AddMemberFromDir
                |         Creates a member object using a direction object as a line or a plane.
                |         
                |     AddMemberFromMathDir
                |         Creates a member object using a mathematical definition of the
                |         direction. 
                |     AddMemberFromMathPlane
                |         Creates a member object from a mathematical definition of a plane.
                |         
                |     AddMemberOnSupport
                |         Creates a member object on a given support. 
                |     AddMemberOnSupportWithRef
                |         Creates a member object on a given support object and a surface used to
                |         define the orientation of the section. 
                |     AddPlate
                |         Creates a plate from a contour defined by coordinates.
                |         
                |     AddPlateOnSurface
                |         Creates a plate from a surface. 
                |     AddRectangularEndPlate
                |         Creates a rectangular end plate on an extremity of a given member.
                |         
                |     AddSection
                |         Creates a section object from part document. 
                |     AddSectionFromCatalog
                |         Creates a section object from part document. 
                |     ExtendProductAsFoundation
                |         Extend an assembly as a structure foundation assembly.
                |         
                | 
                |     Methods
                | 
                | o Func AddDefExtFromCoordinates(	CATSafeArrayVariant 	iCoord,
                | 	double 	iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from coordinates and an offset
                |     value.
                | 
                |     Parameters:
                | 
                |         iCoord
                |             The coordinates of the extremity 
                |         iOffset
                |             The offset on this extremity
                | 
                | o Func AddDefExtFromReference(	Reference 	iReference,
                | 	double 	iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from an existing object in the
                |     model and an offset value.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The reference object defining the extremity 
                |         iOffset
                |             The offset on this extremity
                | 
                | o Func AddDefExtOnMember(	StrMember 	iMember,
                | 	CatStrMemberExtremity 	iSide,
                | 	double 	iDistance,
                | 	double 	iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from another member object,
                |     its side, a distance on it and an offset.
                | 
                |     Parameters:
                | 
                |         iMember
                |             The member used to define the extremity 
                |         iSide
                |             The side of the previous member used to define the distance along
                |             the member 
                |         iDistance
                |             The distance along the selected member 
                |         iOffset
                |             The offset on the extremity 
                | 
                | o Func AddDimMember(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	CATSafeArrayVariant 	iMathDirection,
                | 	double 	iLength,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a dimension member object from a point and a mathematical
                |     definition of a direction.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iMathDirection
                |             The mathematical definition of the direction 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddDimMemberOnPlane(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATSafeArrayVariant 	iDirection,
                | 	CatStrPlaneMode 	iMode,
                | 	double 	iLength,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a dimension member object on a plane following a mathematical
                |     definition of a plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The direction object. It can be a line or a plane 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iOrientation
                |             The orientation of the member 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddDimMemberPtPt(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	double 	iLength,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a dimension member object from two given points.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddDimMemberWithSupport(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	Reference 	iDirection,
                | 	CatStrPlaneMode 	iMode,
                | 	CatStrMaterialOrientation 	iOrientation,
                | 	double 	iLength,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a dimension member object using a support object.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. In case
                |             of line for a support, this parameter is not taking into account.
                |             
                |         iDirection
                |             The direction object. It can be a line or a plane 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iOrientation
                |             The orientation of the member 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member
                | 
                | o Func AddMember(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddMemberFromDir(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	Reference 	iDirection,
                | 	CatStrPlaneMode 	iMode,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object using a direction object as a line or a
                |     plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The direction object used to orientate the support. The direction
                |             object can be a plane or a line. 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddMemberFromMathDir(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATSafeArrayVariant 	iDirection,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object using a mathematical definition of the
                |     direction.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The mathematical definition of the direction 
                |         iType
                |             The type of the member. This type is user defined.
                |             
                | 
                | o Func AddMemberFromMathPlane(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATSafeArrayVariant 	iPlane,
                | 	CatStrPlaneMode 	iPlaneMode,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object from a mathematical definition of a
                |     plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The mathematical definition of a plane 
                |         iPlaneMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddMemberOnSupport(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	double 	iAngle,
                | 	Reference 	iSupport,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object on a given support.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iSupport
                |             The support for the member. The support can be a line or a curve
                |             
                |         iDefExtr1
                |             The extremity object defining the start limit of the member. It can
                |             be NULL. 
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. It can
                |             be NULL. 
                |         iType
                |             The type of the member. This type is user defined.
                |             
                | 
                | o Func AddMemberOnSupportWithRef(	StrSection 	iSection,
                | 	CATBSTR 	iAnchorName,
                | 	Reference 	iSurfRef,
                | 	double 	iAngle,
                | 	Reference 	iSupport,
                | 	AnyObject 	iDefExtr1,
                | 	AnyObject 	iDefExtr2,
                | 	CATBSTR 	iType) As StrMember
                | 
                |     Creates a member object on a given support object and a surface used to
                |     define the orientation of the section. The surface reference defines the
                |     relative orientation on which you add an angle.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iReference
                |             The reference to define the zero orientation of the section. The
                |             section follows this guide line along the support of the member.
                |             
                |         iAngle
                |             The orientation of the section on its support 
                |         iSupport
                |             The support for the member. The support can be a line or a curve
                |             
                |         iDefExtr1
                |             The extremity object defining the start limit of the member. It can
                |             be NULL. 
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. It can
                |             be NULL. 
                |         iType
                |             The type of the member. This type is user defined.
                | 
                | o Func AddPlate(	Reference 	iSupport,
                | 	double 	iThickness,
                | 	CatStrMaterialOrientation 	iOrientation,
                | 	CATSafeArrayVariant 	iContour,
                | 	double 	iOffset,
                | 	CATBSTR 	iType) As StrPlate
                | 
                |     Creates a plate from a contour defined by coordinates.
                | 
                |     Parameters:
                | 
                |         iSupport
                |             The plane defining the support of the plate 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iOrientation
                |             The material orientation of the plate 
                |         iContour
                |             The array containing all objects defining the contour of the plate
                |             
                |         iOffset
                |             The offset applies to the support of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.
                | 
                | o Func AddPlateOnSurface(	double 	iThickness,
                | 	CatStrMaterialOrientation 	iOrientation,
                | 	Reference 	iSurface,
                | 	double 	iOffset,
                | 	CATBSTR 	iType) As StrPlate
                | 
                |     Creates a plate from a surface.
                | 
                |     Parameters:
                | 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iOrientation
                |             The material orientation of the plate 
                |         iSurface
                |             The surface on which plate is to be created. If Surface path is
                |             NULL then method will return E_INVALID_ARG 
                |         iOffset
                |             The offset applies to the support of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.
                | 
                | o Func AddRectangularEndPlate(	StrMember 	iMember,
                | 	CatStrMemberExtremity 	iSide,
                | 	double 	iThickness,
                | 	double 	iHeight,
                | 	double 	iWidth,
                | 	CatStrMaterialOrientation 	iOrientation,
                | 	CATBSTR 	iType) As StrPlate
                | 
                |     Creates a rectangular end plate on an extremity of a given
                |     member.
                | 
                |     Parameters:
                | 
                |         iMember
                |             The member on which the end-plate will be created 
                |         iSide
                |             The side of the selected member 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iHeight
                |             The height of the plate 
                |         iWidth
                |             The width of the plate 
                |         iOrientation
                |             The material orientation of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.
                | 
                | o Func AddSection(	Document 	iPart) As StrSection
                | 
                |     Creates a section object from part document. This part must aggregate a
                |     sketch object defining the contour of the section. The contour of the section
                |     have to be closed and may contain several domains.
                | 
                |     Parameters:
                | 
                |         iPart
                |             The part document where the sketch of the section is
                |             defined
                | 
                | o Func AddSectionFromCatalog(	Document 	iPart,
                | 	CATBSTR 	iCatalogName,
                | 	CATBSTR 	iFamilyName,
                | 	CATBSTR 	iSectionName) As StrSection
                | 
                |     Creates a section object from part document. This part must aggregate a
                |     sketch object defining the contour of the section. This service gives you to
                |     define where the resolved part comes from to allow a replace mechanism. The
                |     contour of the section have to be closed and may contain several
                |     domains.
                | 
                |     Parameters:
                | 
                |         iCatalogName
                |             The catalog name where the document comes from 
                |         iFamilyName
                |             The family name where the document comes from 
                |         iSectionName
                |             The section name where the document comes from 
                |         iPart
                |             The part document where the sketch of the section is
                |             defined
                | 
                | o Func ExtendProductAsFoundation(	CATBSTR 	iClass) As
                | StrFoundation
                | 
                |     Extend an assembly as a structure foundation assembly.
                | 
                |     Parameters:
                | 
                |         iClass
                |             the name of the user class
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_object_factory = com_object

    def add_def_ext_from_coordinates(self, i_coord: tuple, i_offset: float) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDefExtFromCoordinates(CATSafeArrayVariant iCoord,
                | double iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from coordinates and an offset
                |     value.
                | 
                |     Parameters:
                | 
                |         iCoord
                |             The coordinates of the extremity 
                |         iOffset
                |             The offset on this extremity

        :param tuple i_coord:
        :param float i_offset:
        :rtype: AnyObject
        """
        return AnyObject(self.str_object_factory.AddDefExtFromCoordinates(i_coord, i_offset))

    def add_def_ext_from_reference(self, i_reference: Reference, i_offset: float) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDefExtFromReference(Reference iReference,
                | double iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from an existing object in the
                |     model and an offset value.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The reference object defining the extremity 
                |         iOffset
                |             The offset on this extremity

        :param Reference i_reference:
        :param float i_offset:
        :rtype: AnyObject
        """
        return AnyObject(self.str_object_factory.AddDefExtFromReference(i_reference.com_object, i_offset))

    def add_def_ext_on_member(self, i_member: StrMember, i_side: int, i_distance: float, i_offset: float) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDefExtOnMember(StrMember iMember,
                | CatStrMemberExtremity iSide,
                | double iDistance,
                | double iOffset) As AnyObject
                | 
                |     Creates a member extremity definition object from another member object,
                |     its side, a distance on it and an offset.
                | 
                |     Parameters:
                | 
                |         iMember
                |             The member used to define the extremity 
                |         iSide
                |             The side of the previous member used to define the distance along
                |             the member 
                |         iDistance
                |             The distance along the selected member 
                |         iOffset
                |             The offset on the extremity

        :param StrMember i_member:
        :param int i_side: enum cat_str_member_extremity
        :param float i_distance:
        :param float i_offset:
        :rtype: AnyObject
        """
        return AnyObject(self.str_object_factory.AddDefExtOnMember(i_member.com_object, i_side, i_distance, i_offset))

    def add_dim_member(self,
                       i_section: StrSection,
                       i_anchor_name: str,
                       i_angle: float,
                       i_def_extr1: AnyObject,
                       i_math_direction: tuple,
                       i_length: float,
                       i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDimMember(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | CATSafeArrayVariant iMathDirection,
                | double iLength,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a dimension member object from a point and a mathematical
                |     definition of a direction.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iMathDirection
                |             The mathematical definition of the direction 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param tuple i_math_direction:
        :param float i_length:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddDimMember(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_math_direction,
                i_length,
                i_type
            )
        )

    def add_dim_member_on_plane(self,
                                i_section: StrSection,
                                i_anchor_name: str,
                                i_angle: float,
                                i_def_extr1: AnyObject,
                                i_def_extr2: AnyObject,
                                i_direction: tuple,
                                i_mode: int,
                                i_length: float,
                                i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDimMemberOnPlane(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATSafeArrayVariant iDirection,
                | CatStrPlaneMode iMode,
                | double iLength,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a dimension member object on a plane following a mathematical
                |     definition of a plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The direction object. It can be a line or a plane 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iOrientation
                |             The orientation of the member 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param tuple i_direction:
        :param int i_mode: enum cat_str_plane_mode
        :param float i_length:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddDimMemberOnPlane(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_direction,
                i_mode,
                i_length,
                i_type
            )
        )

    def add_dim_member_pt_pt(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_length: float,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDimMemberPtPt(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | double iLength,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a dimension member object from two given points.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param float i_length:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddDimMemberPtPt(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_length,
                i_type
            )
        )

    def add_dim_member_with_support(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_direction: Reference,
            i_mode: int,
            i_orientation: int,
            i_length: float,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddDimMemberWithSupport(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | Reference iDirection,
                | CatStrPlaneMode iMode,
                | CatStrMaterialOrientation iOrientation,
                | double iLength,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a dimension member object using a support object.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. In case
                |             of line for a support, this parameter is not taking into account.
                |             
                |         iDirection
                |             The direction object. It can be a line or a plane 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iOrientation
                |             The orientation of the member 
                |         iLength
                |             The length of the member 
                |         iType
                |             The type of the member

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param Reference i_direction:
        :param int i_mode: enum cat_str_plane_mode
        :param int i_orientation: enum cat_str_material_orientation
        :param float i_length:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddDimMemberWithSupport(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_direction.com_object,
                i_mode,
                i_orientation,
                i_length,
                i_type
            )
        )

    def add_member(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMember(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMember(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_type
            )
        )

    def add_member_from_dir(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_direction: Reference,
            i_mode: int,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMemberFromDir(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | Reference iDirection,
                | CatStrPlaneMode iMode,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object using a direction object as a line or a
                |     plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The direction object used to orientate the support. The direction
                |             object can be a plane or a line. 
                |         iMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param Reference i_direction:
        :param int i_mode: enum cat_str_plane_mode
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMemberFromDir(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_direction.com_object,
                i_mode,
                i_type
            )
        )

    def add_member_from_math_dir(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_direction: tuple,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMemberFromMathDir(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATSafeArrayVariant iDirection,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object using a mathematical definition of the
                |     direction.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The mathematical definition of the direction 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param tuple i_direction:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMemberFromMathDir(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_direction,
                i_type)
        )

    def add_member_from_math_plane(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_plane: tuple,
            i_plane_mode: int,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMemberFromMathPlane(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATSafeArrayVariant iPlane,
                | CatStrPlaneMode iPlaneMode,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object from a mathematical definition of a
                |     plane.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iDefExtr1
                |             The extremity object defining the start limit of the member
                |             
                |         iDefExtr2
                |             The extremity object defining the end limit of the member
                |             
                |         iDirection
                |             The mathematical definition of a plane 
                |         iPlaneMode
                |             The way the member is created with respect to the direction plane.
                |             Useless if if the direction is not a plane. 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param tuple i_plane:
        :param int i_plane_mode: enum cat_str_plane_mode
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMemberFromMathPlane(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_plane,
                i_plane_mode,
                i_type
            )
        )

    def add_member_on_support(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_angle: float,
            i_support: Reference,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMemberOnSupport(StrSection iSection,
                | CATBSTR iAnchorName,
                | double iAngle,
                | Reference iSupport,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object on a given support.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iAngle
                |             The orientation of the section on its support 
                |         iSupport
                |             The support for the member. The support can be a line or a curve
                |             
                |         iDefExtr1
                |             The extremity object defining the start limit of the member. It can
                |             be NULL. 
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. It can
                |             be NULL. 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param float i_angle:
        :param Reference i_support:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMemberOnSupport(
                i_section.com_object,
                i_anchor_name,
                i_angle,
                i_support.com_object,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_type
            )
        )

    def add_member_on_support_with_ref(
            self,
            i_section: StrSection,
            i_anchor_name: str,
            i_surf_ref: Reference,
            i_angle: float,
            i_support: Reference,
            i_def_extr1: AnyObject,
            i_def_extr2: AnyObject,
            i_type: str) -> StrMember:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddMemberOnSupportWithRef(StrSection iSection,
                | CATBSTR iAnchorName,
                | Reference iSurfRef,
                | double iAngle,
                | Reference iSupport,
                | AnyObject iDefExtr1,
                | AnyObject iDefExtr2,
                | CATBSTR iType) As StrMember
                | 
                |     Creates a member object on a given support object and a surface used to
                |     define the orientation of the section. The surface reference defines the
                |     relative orientation on which you add an angle.
                | 
                |     Parameters:
                | 
                |         iSection
                |             The section object defining the profile for the member
                |             
                |         iAnchorName
                |             The name of the anchor point 
                |         iReference
                |             The reference to define the zero orientation of the section. The
                |             section follows this guide line along the support of the member.
                |             
                |         iAngle
                |             The orientation of the section on its support 
                |         iSupport
                |             The support for the member. The support can be a line or a curve
                |             
                |         iDefExtr1
                |             The extremity object defining the start limit of the member. It can
                |             be NULL. 
                |         iDefExtr2
                |             The extremity object defining the end limit of the member. It can
                |             be NULL. 
                |         iType
                |             The type of the member. This type is user defined.

        :param StrSection i_section:
        :param str i_anchor_name:
        :param Reference i_surf_ref:
        :param float i_angle:
        :param Reference i_support:
        :param AnyObject i_def_extr1:
        :param AnyObject i_def_extr2:
        :param str i_type:
        :rtype: StrMember
        """
        return StrMember(
            self.str_object_factory.AddMemberOnSupportWithRef(
                i_section.com_object,
                i_anchor_name,
                i_surf_ref.com_object,
                i_angle,
                i_support.com_object,
                i_def_extr1.com_object,
                i_def_extr2.com_object,
                i_type
            )
        )

    def add_plate(
            self,
            i_support: Reference,
            i_thickness: float,
            i_orientation: int,
            i_contour: tuple,
            i_offset: float,
            i_type: str) -> StrPlate:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddPlate(Reference iSupport,
                | double iThickness,
                | CatStrMaterialOrientation iOrientation,
                | CATSafeArrayVariant iContour,
                | double iOffset,
                | CATBSTR iType) As StrPlate
                | 
                |     Creates a plate from a contour defined by coordinates.
                | 
                |     Parameters:
                | 
                |         iSupport
                |             The plane defining the support of the plate 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iOrientation
                |             The material orientation of the plate 
                |         iContour
                |             The array containing all objects defining the contour of the plate
                |             
                |         iOffset
                |             The offset applies to the support of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.

        :param Reference i_support:
        :param float i_thickness:
        :param int i_orientation: enum cat_str_material_orientation
        :param tuple i_contour:
        :param float i_offset:
        :param str i_type:
        :rtype: StrPlate
        """
        return StrPlate(
            self.str_object_factory.AddPlate(
                i_support.com_object,
                i_thickness,
                i_orientation,
                i_contour,
                i_offset,
                i_type
            )
        )

    def add_plate_on_surface(
            self,
            i_thickness: float,
            i_orientation: int,
            i_surface: Reference,
            i_offset: float,
            i_type: str) -> StrPlate:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddPlateOnSurface(double iThickness,
                | CatStrMaterialOrientation iOrientation,
                | Reference iSurface,
                | double iOffset,
                | CATBSTR iType) As StrPlate
                | 
                |     Creates a plate from a surface.
                | 
                |     Parameters:
                | 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iOrientation
                |             The material orientation of the plate 
                |         iSurface
                |             The surface on which plate is to be created. If Surface path is
                |             NULL then method will return E_INVALID_ARG 
                |         iOffset
                |             The offset applies to the support of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.

        :param float i_thickness:
        :param int i_orientation: enum cat_str_material_orientation
        :param Reference i_surface:
        :param float i_offset:
        :param str i_type:
        :rtype: StrPlate
        """
        return StrPlate(
            self.str_object_factory.AddPlateOnSurface(
                i_thickness,
                i_orientation,
                i_surface.com_object,
                i_offset,
                i_type
            )
        )

    def add_rectangular_end_plate(
            self,
            i_member: StrMember,
            i_side: int,
            i_thickness: float,
            i_height: float,
            i_width: float,
            i_orientation: int,
            i_type: str) -> StrPlate:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRectangularEndPlate(StrMember iMember,
                | CatStrMemberExtremity iSide,
                | double iThickness,
                | double iHeight,
                | double iWidth,
                | CatStrMaterialOrientation iOrientation,
                | CATBSTR iType) As StrPlate
                | 
                |     Creates a rectangular end plate on an extremity of a given
                |     member.
                | 
                |     Parameters:
                | 
                |         iMember
                |             The member on which the end-plate will be created 
                |         iSide
                |             The side of the selected member 
                |         iThickness
                |             The standard thickness of the plate. The thickness follows the
                |             standard orientation of the support 
                |         iHeight
                |             The height of the plate 
                |         iWidth
                |             The width of the plate 
                |         iOrientation
                |             The material orientation of the plate 
                |         iType
                |             The type of the plate. This information is user defined. It is
                |             added as an attribute on the plate.

        :param StrMember i_member:
        :param int i_side: enum cat_str_member_extremity
        :param float i_thickness:
        :param float i_height:
        :param float i_width:
        :param int i_orientation: enum cat_str_material_orientation
        :param str i_type:
        :rtype: StrPlate
        """
        return StrPlate(
            self.str_object_factory.AddRectangularEndPlate(
                i_member.com_object,
                i_side,
                i_thickness,
                i_height,
                i_width,
                i_orientation,
                i_type
            )
        )

    def add_section(self, i_part: Document) -> StrSection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddSection(Document iPart) As StrSection
                | 
                |     Creates a section object from part document. This part must aggregate a
                |     sketch object defining the contour of the section. The contour of the section
                |     have to be closed and may contain several domains.
                | 
                |     Parameters:
                | 
                |         iPart
                |             The part document where the sketch of the section is
                |             defined

        :param Document i_part:
        :rtype: StrSection
        """
        return StrSection(self.str_object_factory.AddSection(i_part.com_object))

    def add_section_from_catalog(
            self,
            i_part: Document,
            i_catalog_name: str,
            i_family_name: str,
            i_section_name: str) -> StrSection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddSectionFromCatalog(Document iPart,
                | CATBSTR iCatalogName,
                | CATBSTR iFamilyName,
                | CATBSTR iSectionName) As StrSection
                | 
                |     Creates a section object from part document. This part must aggregate a
                |     sketch object defining the contour of the section. This service gives you to
                |     define where the resolved part comes from to allow a replace mechanism. The
                |     contour of the section have to be closed and may contain several
                |     domains.
                | 
                |     Parameters:
                | 
                |         iCatalogName
                |             The catalog name where the document comes from 
                |         iFamilyName
                |             The family name where the document comes from 
                |         iSectionName
                |             The section name where the document comes from 
                |         iPart
                |             The part document where the sketch of the section is
                |             defined

        :param Document i_part:
        :param str i_catalog_name:
        :param str i_family_name:
        :param str i_section_name:
        :rtype: StrSection
        """
        return StrSection(
            self.str_object_factory.AddSectionFromCatalog(
                i_part.com_object,
                i_catalog_name,
                i_family_name,
                i_section_name
            )
        )

    def extend_product_as_foundation(self, i_class: str) -> StrFoundation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ExtendProductAsFoundation(CATBSTR iClass) As
                | StrFoundation
                | 
                |     Extend an assembly as a structure foundation assembly.
                | 
                |     Parameters:
                | 
                |         iClass
                |             the name of the user class

        :param str i_class:
        :rtype: StrFoundation
        """
        return StrFoundation(self.str_object_factory.ExtendProductAsFoundation(i_class))

    def __repr__(self):
        return f'StrObjectFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.knowledge_object import KnowledgeObject


class KnowledgeActivateObject(KnowledgeObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                         KnowledgeActivateObject
                | 
                | Interface to access a CATIAKnowledgeActivableObject.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.knowledge_activate_object = com_object

    @property
    def activated(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Activated() As boolean (Read Only)
                | 
                |     Returns whether the relation is activated.
                |     True if the relation is activated. An activated relation is processed
                |     whenever the value of one of its input parameter is
                |     modified.
                | 
                |     Example:
                |         This example retrieves whether the maximummass relation is activated,
                |         and if true, displays the result in a message box:
                | 
                |          If ( maximummass.Activated ) Then
                |               MsgBox "maximummass is activated"
                |          End If

        :rtype: bool
        """

        return self.knowledge_activate_object.Activated

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Activate()
                | 
                |     Activates the relation. The relation will be processed whenever the value
                |     of one of its input parameter is modified.
                | 
                |     Example:
                |         This example activates the maximummass relation:
                | 
                |          maximummass.Activate()

        :rtype: None
        """
        return self.knowledge_activate_object.Activate()

    def deactivate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Deactivate()
                | 
                |     Deactivates the relation. The relation will no longer be processed when the
                |     value of one of its input parameter is modified.
                | 
                |     Example:
                |         This example deactivates the maximummass relation:
                | 
                |          maximummass.Deactivate()

        :rtype: None
        """
        return self.knowledge_activate_object.Deactivate()

    def __repr__(self):
        return f'KnowledgeActivateObject(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingToolMotion(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingToolMotion
                | 
                | A ManufacturingToolMotion for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_tool_motion = com_object

    def get_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retrieve by is name the attribute of a Manufacturing
                |     ToolMotion.
                |     Each attribute is a CKE object.
                | 
                |     Example:
                |         The following example retreives in Diameter the attribute MfgDiameter
                |         of the Manufacturing ToolMotion firstToolmotion
                | 
                |          Set Diameter = firstToolmotion.GetAttribute(MfgDiameter)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_tool_motion.GetAttribute(i_attribute))

    def get_feedrate(self, o_feedrate: float) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFeedrate(double oFeedrate) As CATBSTR
                | 
                |     Retrieves the Feedrate of a Manufacturing Point to point
                |     ToolMotion.
                |     If the ToolMotion is not a Manufacturing Point to point, nothing is
                |     done.
                | 
                |     Parameters:
                | 
                |         oFeedrateType
                |             Legal values: oFeedrateType can be:
                | 
                |             "RAPID"
                |             "LOCAL"
                |             "NONE"
                | 
                |         oFeedrate
                |             Feedrate value. (expressed in MKS units : m/s if linear feedrate, or m/turn if angular feedrate)
                |             Feedrate value has a meaning only if oFeedrateType is "LOCAL"
                |
                |     Example:
                |         The following example gets the feedrate type of a Manufacturing Point
                |         To Point Toolmotion submotion1
                | 
                |          dim FeedVal as double
                |          dim FeedType as CATBSTR
                |          FeedType=SubMotion1.GetFeedrate(FeedVal)

        :param float o_feedrate:
        :rtype: str
        """
        return self.manufacturing_tool_motion.GetFeedrate(o_feedrate)

    def get_goto_pt_point_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetGotoPtPointCoordinates(double oX,
                | double oY,
                | double oZ)
                | 
                |     Retrieves coordinates on the ToolMotion.
                |     If the type of the ToolMotion is not MfgSeqMotionPoint, nothing is
                |     done.
                |     These coordinates are expressed in the current axis
                |     system.
                |     Coordinates units are millimeters.
                | 
                |     Example:
                |         The following example gets coordinates on a Manufacturing Point To
                |         Point Toolmotion submotion1
                | 
                |          dim XCoord as double
                |          dim YCoord as double
                |          dim ZCoord as double
                |          Call SubMotion1.GetGotoPtPointCoordinates(XCoord, YCoord,
                |          ZCoord)

        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """
        return self.manufacturing_tool_motion.GetGotoPtPointCoordinates()

    def get_pp_word(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPPWord() As CATBSTR
                | 
                |     Retrieves the content of a Manufacturing PP Word
                |     ToolMotion.
                | 
                |     Example:
                |         The following example retrieves in Message the content of the
                |         Manufacturing PPWord Toolmotion firstToolmotion
                | 
                |          dim Message as CATBSTR
                |          Message = firstToolmotion.GetPPWord

        :rtype: str
        """
        return self.manufacturing_tool_motion.GetPPWord()

    def get_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetType() As CATBSTR
                | 
                |     Retrieves the type of a Manufacturing ToolMotion.
                | 
                |     Parameters:
                | 
                |         oType
                |             Legal values: oType can be:
                | 
                |             "MfgSeqMotionPoint"
                |             "MfgSeqMotionPosition"
                |             "MfgSeqMotionDelta"
                | 
                |     Example:
                |         The following example retrieves in ThisType the type of the
                |         Manufacturing Toolmotion firstToolMotion
                | 
                |          dim ThisType as CATBSTR
                |          Set ThisType = firstToolMotion.GetType

        :rtype: str
        """
        return self.manufacturing_tool_motion.GetType()

    def set_feedrate(self, i_feedrate: float, i_feedrate_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFeedrate(double iFeedrate,
                | CATBSTR iFeedrateType)
                | 
                |     Defines the feedrate of a Manufacturing Point to point
                |     ToolMotion.
                |     If the ToolMotion is not a Manufacturing Point to point, nothing is
                |     done.
                | 
                |     Parameters:
                | 
                |         iFeedrateType
                |             Legal values: iFeedrateType can be:
                | 
                |             "RAPID"
                |             "LOCAL"
                |             "NONE"
                | 
                |         oFeedrate
                |             Feedrate value. (expressed in MKS units : m/s if linear feedrate, or m/turn if angular feedrate)
                |             Feedrate value is taken into account only if iFeedrateType is
                |             "LOCAL" 
                | 
                |     Example:
                |         The following example sets a local feedrate on a Manufacturing Point To
                |         Point Toolmotion submotion1
                | 
                |          dim FeedVal as double
                |          dim FeedType as CATBSTR
                |          FeedVal = 169.0
                |          FeedType="LOCAL"
                |          Call SubMotion1.SetFeedrate(FeedVal, FeedType)

        :param float i_feedrate:
        :param str i_feedrate_type:
        :rtype: None
        """
        return self.manufacturing_tool_motion.SetFeedrate(i_feedrate, i_feedrate_type)

    def set_goto_pt_point_coordinates(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGotoPtPointCoordinates(double iX,
                | double iY,
                | double iZ)
                | 
                |     Defines coordinates on the ToolMotion.
                |     If the type of the ToolMotion is not MfgSeqMotionPoint, nothing is
                |     done.
                |     These coordinates are expressed in the current axis
                |     system.
                |     Coordinates units are millimeters.
                | 
                |     Example:
                |         The following example sets coordinates on a Manufacturing Point To
                |         Point Toolmotion submotion1
                | 
                |          dim XCoord as double
                |          dim YCoord as double
                |          dim ZCoord as double
                |          XCoord = 10.0
                |          YCoord = 20.0
                |          ZCoord = 5.0
                |          Call SubMotion1.SetGotoPtPointCoordinates(XCoord, YCoord,
                |          ZCoord)

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.manufacturing_tool_motion.SetGotoPtPointCoordinates(i_x, i_y, i_z)

    def set_pp_word(self, i_message: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPPWord(CATBSTR iMessage)
                | 
                |     Adds a line containing iMessage to a Manufacturing PP Word
                |     ToolMotion.
                | 
                |     Example:
                |         The following example adds the line Message to the content of the
                |         Manufacturing PPWord Toolmotion firstToolmotion
                | 
                |          firstToolmotion.SetPPWord("Message")

        :param str i_message:
        :rtype: None
        """
        return self.manufacturing_tool_motion.SetPPWord(i_message)

    def __repr__(self):
        return f'ManufacturingToolMotion(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_entity import AnalysisEntity
from pycatia.analysis_interfaces.analysis_images import AnalysisImages
from pycatia.system_interfaces.any_object import AnyObject


class ABQImageQuery(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQImageQuery
                | 
                | Provides an image query object.
                | 
                | Role: Use to query result images for values on nodes / elements / groups. Image query can be done simultaneously for multiple images. User can call methods such as ExportImageData or ExportGroupImageData. Use following method to get an object of ABQImageQuery Dim abqCase As ABQAnalysisCase Dim ImageQuery As ABQImageQuery Set ImageQuery = abqCase.GetItem ("ABQVBImageQuery")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_image_query = com_object

    def export_group_image_data(
            self,
            i_images_list: AnalysisImages,
            i_group: AnalysisEntity,
            i_type: int,
            i_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportGroupImageData(AnalysisImages iImagesList,
                | AnalysisEntity iGroup,
                | ABQEntityType iType,
                | CATBSTR iFile)
                | 
                |     Method to export image data in text or excel format for a
                |     group.
                |     The data in a row will be in following order: Node / element id, X
                |     coordinate, Y coordinate, Z coordinate, value for image 1, value for image 2,
                |     ...
                | 
                |     File type will be identified using file extension. If file extension is
                |     'xls' then it will be exported in excel otherwise the file type will be
                |     considered as text
                | 
                |     Parameters:
                | 
                |         iImagesList
                |             List of images to export 
                |         iGroup
                |             CATIA group or display group to query image data 
                |         iType
                |             Entity type to query.
                |             Legal values
                | 
                |             ABQ_NODE
                |             ABQ_ELEMENT
                | 
                |         iFile
                |             File path to export data. 
                |         Example:
                |             The following example exports image query data to specified
                |             file
                | 
                |              Dim ImageQuery As ABQImageQuery
                |              Dim File As FileSystem
                |              Dim MyGroup As AnalysisEntity
                |              Dim imageList As AnalysisImages
                |              ImageQuery.ExportImageData imageList, MyGroup, ABQ_NODE,
                |              File

        :param AnalysisImages i_images_list:
        :param AnalysisEntity i_group:
        :param int i_type: enum abq_entity_type
        :param str i_file:
        :rtype: None
        """
        return self.abq_image_query.ExportGroupImageData(i_images_list.com_object, i_group.com_object, i_type, i_file)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_group_image_data'
        # # vba_code = """
        # # Public Function export_group_image_data(abq_image_query)
        # #     Dim iImagesList (2)
        # #     abq_image_query.ExportGroupImageData iImagesList
        # #     export_group_image_data = iImagesList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_image_data(self, i_images_list: AnalysisImages, i_list_numbers: tuple, i_type: int, i_file: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportImageData(AnalysisImages iImagesList,
                | CATSafeArrayVariant iListNumbers,
                | ABQEntityType iType,
                | CATBSTR iFile)
                | 
                |     Method to export image data in text or excel format.
                |     The data in a row will be in following order: Node / element id, X
                |     coordinate, Y coordinate, Z coordinate, value for image 1, value for image 2,
                |     ...
                | 
                |     File type will be identified using file extension. If file extension is
                |     'xls' then it will be exported in excel otherwise the file type will be
                |     considered as text
                | 
                |     Parameters:
                | 
                |         iImagesList
                |             List of images to export 
                |         iListNumbers
                |             List of entity indices to export (node numbers or element numbers)
                |             
                |         iType
                |             Entity type to query.
                |             Legal values
                | 
                |             ABQ_NODE
                |             ABQ_ELEMENT
                | 
                |         iFile
                |             File path to export data 
                |         Example:
                |             The following example exports image query data to specified
                |             file
                | 
                |              Dim ImageQuery As ABQImageQuery
                |              Dim File As FileSystem
                |              Dim EntityList As CATSafeArrayVariant
                |              Dim imageList As AnalysisImages
                |              ImageQuery.ExportImageData imageList, EntityList, ABQ_NODE,
                |              File

        :param AnalysisImages i_images_list:
        :param tuple i_list_numbers:
        :param int i_type: enum abq_entity_type
        :param str i_file:
        :rtype: None
        """
        return self.abq_image_query.ExportImageData(i_images_list.com_object, i_list_numbers, i_type, i_file)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_image_data'
        # # vba_code = """
        # # Public Function export_image_data(abq_image_query)
        # #     Dim iImagesList (2)
        # #     abq_image_query.ExportImageData iImagesList
        # #     export_image_data = iImagesList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQImageQuery(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.specs_viewer import SpecsViewer
from pycatia.in_interfaces.window import Window


class SpecsAndGeomWindow(Window):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Window
                |                         SpecsAndGeomWindow
                | 
                | Represents a window featuring a specification viewer and a geometry
                | viewer.
                | The specification viewer is located in the left part of the window and displays
                | the document's specification tree. The geometry viewer is located in the right
                | part of the window and displays the document's geometry, and can thus be a
                | Viewer2D or a Viewer3D, according to the document type. Even if generally the
                | two viewers are simultaneously displayed, one viewer or the other can be hidden
                | thanks to the CatSpecsAndGeomWindowLayout enumeration.
                | 
                | See also:
                |     CatSpecsAndGeomWindowLayout
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.specs_and_geom_window = com_object

    @property
    def layout(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Layout() As CatSpecsAndGeomWindowLayout
                | 
                |     Returns or sets the specification and geometry window
                |     layout.
                | 
                |     Example:
                |         This example sets the specification and geometry window layout for the
                |         MyCADWindow window to catWindowGeomOnly.
                | 
                |          MyCADWindow.Layout = catWindowGeomOnly

        :return: enum cat_specs_and_geom_window_layout
        :rtype: int
        """

        return self.specs_and_geom_window.Layout

    @layout.setter
    def layout(self, value: int):
        """
        :param int value: enum cat_specs_and_geom_window_layout
        """

        self.specs_and_geom_window.Layout = value

    @property
    def specs_viewer(self) -> SpecsViewer:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SpecsViewer() As SpecsViewer (Read Only)
                | 
                |     Returns the specifications viewer.
                | 
                |     Example:
                |         This example retrieves the specification viewer for the MyCADWindow
                |         window.
                | 
                |          Dim MyViewer As Viewer
                |          Set MyViewer = MyCADWindow.SpecsViewer

        :rtype: SpecsViewer
        """

        return SpecsViewer(self.specs_and_geom_window.SpecsViewer)

    def __repr__(self):
        return f'SpecsAndGeomWindow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class TCPTrace(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TCPTrace
                | 
                | Interface representing a TCP trace.
                | 
                | Role: This interface is used to interact with an inverse kinematics device on
                | which a TCP(Tool Center Point) has been defined.
                | 
                | A TCP trace is the graphical output of a task simulation. This output is the
                | trajectory path generated by the TCP, defined by lines and points. Each point
                | represents the location of the TCP at a given time.
                | 
                | The following code snippet can be used to obtain a handle from a
                | product:
                | 
                |    Dim MyRobot As Product
                |    'retrieval of the product
                |    ...
                | 
                |    'retrieval of the trace manager
                |    Dim objDevice As TCPTraceManager
                |    set objDevice = MyRobot.GetTechnologicalObject("TCPTraceManager")
                |    
                |    'activate the trace
                |    objDevice.TCPTraceMode=True
                | 
                |    'Get the last path
                |    Dim NbPath As Long
                |    NbPath = objDevice.GetNbPath
                |    If NbPath>0 Then
                |       ' retrieval of the last trace
                |       Dim RobotTCPTrace As TCPTrace
                |       Set RobotTCPTrace = objDevice.GetPath(NbPath)
                | 
                |       'Export the trace points
                |       RobotTCPTrace.Export("C:/TEMP/DEBUG.xls")
                |    End If
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tcp_trace = com_object

    @property
    def total_points(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TotalPoints() As long (Read Only)
                | 
                |     Returns the number of points in the trace.
                | 
                |     Parameters:
                | 
                |         oNbPoints
                |             Long. Contains the number of points.

        :rtype: int
        """

        return self.tcp_trace.TotalPoints

    @property
    def trace_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TraceName() As CATBSTR
                | 
                |     Manage the name of the trace. Property can be retrieved and
                |     valuated
                | 
                |     Parameters:
                | 
                |         oName
                |             CATBSTR. String containing the retrieved name.

        :rtype: str
        """

        return self.tcp_trace.TraceName

    @trace_name.setter
    def trace_name(self, value: str):
        """
        :param str value:
        """

        self.tcp_trace.TraceName = value

    @property
    def visibility(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Visibility() As boolean
                | 
                |     Manage the visibility of the trace. Property can be retrieved and
                |     valuated
                | 
                |         1: shown
                |         0: hidden
                | 
                |     Parameters:
                | 
                |         oVisibility
                |             Boolean. Contains the return value.

        :rtype: bool
        """

        return self.tcp_trace.Visibility

    @visibility.setter
    def visibility(self, value: bool):
        """
        :param bool value:
        """

        self.tcp_trace.Visibility = value

    def export(self, i_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Export(CATBSTR iName) As long
                | 
                |     Export the TCP trace data in a file. The file format is indicated by the
                |     iFileName extension. Only Excel(Windows NT only) and text files are supported.
                |     If there is already a file at the given location, the user is prompted to
                |     override the file.
                | 
                |     Example :
                |      iFileName = C:/TEMP/MyFile.xls  -> Excel file
                |      iFileName = /usr/tmp/MyFile.txt -> Text file
                | 
                |     Parameters:
                | 
                |         iName
                |             CATBSTR. Input parameter. File path+name+extension.
                |             
                |         oError
                |             Long. Output parameter. Indicates if any error happened.

        :param str i_name:
        :rtype: int
        """
        return self.tcp_trace.Export(i_name)

    def get_attached_owner(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttachedOwner() As AnyObject
                | 
                |     Retrieves the default attached owner of the trace. By default, the owner of
                |     the trace is the robot assembly node. If the robot is moved, the trace will
                |     follow. However, in some scenarios, the trace might be drawn related to another
                |     product (or even with respect to the world) like for example when dealing with
                |     a workpiece positioner.
                | 
                |     Parameters:
                | 
                |         oOwner
                |             CATIABase. Attached owner of the trace. Output parameter. Returns
                |             nothing if the trace is defined related to the world

        :rtype: AnyObject
        """
        return AnyObject(self.tcp_trace.GetAttachedOwner())

    def get_colour(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetColor(DNBTCPTraceReps iRep,
                | long oR,
                | long oG,
                | long oB,
                | long oA)
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) color.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         oR
                |             Long. Red color component from 0 to 255. Input parameter.
                |             
                |         oG
                |             Long. Green color component from 0 to 255. Input parameter.
                |             
                |         oB
                |             Long. Blue color component from 0 to 255. Input parameter.
                |             
                |         oA
                |             Long. Alpha color component from 0 to 255. Input parameter.


        :return: enum dnbtcp_trace_reps
        :rtype: int
        """
        return self.tcp_trace.GetColor()

    def get_legends_visibility(self, i_type: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLegendsVisibility(DNBTCPTraceLegends iType) As
                | boolean
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) legend visibility status.
                |     Indicates whether or not at (pre)highlight, some text should be
                |     shown.
                | 
                |     Parameters:
                | 
                |         iType
                |             DNBTCPTraceLegends. Define the kind of legend on which the method
                |             will be applied on. Input parameter. 
                |         obVisible
                |             Boolean. Indicates if it is visible(True) or hidden(False). Output
                |             parameter.

        :param int i_type: enum dnbtcp_trace_legends
        :rtype: bool
        """
        return self.tcp_trace.GetLegendsVisibility(i_type)

    def get_thickness(self, i_rep: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetThickness(DNBTCPTraceReps iRep) As long
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) thickness(for line,
                |     axis).
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         oThickness
                |             Indicates the index width of the line in the range [1,55]. This
                |             index is pointing on the true width in pixel, recorded in the standard (if
                |             there is one in the document) or in the setting. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :rtype: int
        """
        return self.tcp_trace.GetThickness(i_rep)

    def get_type(self, i_rep: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetType(DNBTCPTraceReps iRep) As long
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) type. For points, legal
                |     values are :
                | 
                |         1 : CROSS
                |         2 : PLUS
                |         3 : CONCENTRIC
                | 
                |     For line and axis, legal values are :
                | 
                |         1 : solid
                |         2 : dotted
                |         3 : dashed
                |         4 : dot-dashed
                |         5 : phantom
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         oType
                |             Long. Depends on the DNBTCPTraceReps. Output parameter. Output
                |             parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :rtype: int
        """
        return self.tcp_trace.GetType(i_rep)

    def get_visibility(self, i_rep: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisibility(DNBTCPTraceReps iRep) As boolean
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) visibility
                |     status.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         obVisible
                |             Boolean. True for visible and False for hidden. Output parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :rtype: bool
        """
        return self.tcp_trace.GetVisibility(i_rep)

    def refresh_display(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RefreshDisplay()
                | 
                |     Refresh display. Need to call this method whenever the graphic properties
                |     are changed. By default, when changing the graphic properties, the refresh is
                |     not applied for performance reasons. Caller of the API must call RefreshDisplay
                |     to view the changes in the main viewer.

        :rtype: None
        """
        return self.tcp_trace.RefreshDisplay()

    def reset_attached_owner(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetAttachedOwner()
                | 
                |     Resets the attached owner of the trace to the world. When a new trace will
                |     be created, it will defined with respect to the world.
                |     Remark: this will not change the exported values.

        :rtype: None
        """
        return self.tcp_trace.ResetAttachedOwner()

    def reset_graphics(self, b_setting: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetGraphics(boolean bSetting)
                | 
                |     Reset the current appearance regarding the current general settings (not
                |     the one applied on the current object). Call < to see the changes
                |     applied.
                | 
                |     Parameters:
                | 
                |         bSetting
                |             Boolean. Indicates if it is visible(True) or hidden(False). Input
                |             parameter.

        :param bool b_setting:
        :rtype: None
        """
        return self.tcp_trace.ResetGraphics(b_setting)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reset_graphics'
        # # vba_code = """
        # # Public Function reset_graphics(tcp_trace)
        # #     Dim bSetting (2)
        # #     tcp_trace.ResetGraphics bSetting
        # #     reset_graphics = bSetting
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_attached_owner(self, i_owner: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttachedOwner(AnyObject iOwner)
                | 
                |     Sets the default attached owner of the trace. By default, the owner of the
                |     trace is the robot. When a new trace is created, the attached owner is used to
                |     set it upon the trace.
                |     Remark: set the attached owner will not change the exported
                |     values.
                | 
                |     Parameters:
                | 
                |         iOwner
                |             CATIABase. Attached owner of the trace. Input parameter.

        :param AnyObject i_owner:
        :rtype: None
        """
        return self.tcp_trace.SetAttachedOwner(i_owner.com_object)

    def set_color(self, i_rep: int, i_r: int, i_g: int, i_b: int, i_a: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetColor(DNBTCPTraceReps iRep,
                | long iR,
                | long iG,
                | long iB,
                | long iA)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) color. Call < to see the
                |     changes applied.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iR
                |             Long. Red color component from 0 to 255. Input parameter.
                |             
                |         iG
                |             Long. Green color component from 0 to 255. Input parameter.
                |             
                |         iB
                |             Long. Blue color component from 0 to 255. Input parameter.
                |             
                |         iA
                |             Long. Alpha color component from 0 to 255. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_r:
        :param int i_g:
        :param int i_b:
        :param int i_a:
        :rtype: None
        """
        return self.tcp_trace.SetColor(i_rep, i_r, i_g, i_b, i_a)

    def set_legends_visibility(self, i_type: int, ib_visible: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLegendsVisibility(DNBTCPTraceLegends iType,
                | boolean ibVisible)
                | 
                |     Get the TCP trace component (DNBTCPTraceReps) legend visibility status.
                |     Indicates whether or not at (pre)highlight, some text should be shown. Call <
                |     to see the changes applied.
                | 
                |     Parameters:
                | 
                |         iType
                |             DNBTCPTraceLegends. Define the kind of legend on which the method
                |             will be applied on. Input parameter. 
                |         ibVisible
                |             Boolean. Indicates if it is visible(True) or hidden(False). Input
                |             parameter.

        :param int i_type: enum dnbtcp_trace_legends
        :param bool ib_visible:
        :rtype: None
        """
        return self.tcp_trace.SetLegendsVisibility(i_type, ib_visible)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_legends_visibility'
        # # vba_code = """
        # # Public Function set_legends_visibility(tcp_trace)
        # #     Dim iType (2)
        # #     tcp_trace.SetLegendsVisibility iType
        # #     set_legends_visibility = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_thickness(self, i_rep: int, i_thickness: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetThickness(DNBTCPTraceReps iRep,
                | long iThickness)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) thickness(for line, axis).
                |     Call < to see the changes applied.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iThickness
                |             Indicates the index width of the line in the range [1,55]. This
                |             index is pointing on the true width in pixel, recorded in the standard (if
                |             there is one in the document) or in the setting. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_thickness:
        :rtype: None
        """
        return self.tcp_trace.SetThickness(i_rep, i_thickness)

    def set_type(self, i_rep: int, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetType(DNBTCPTraceReps iRep,
                | long iType)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) type. For points, legal
                |     values are :
                | 
                |         1 : CROSS
                |         2 : PLUS
                |         3 : CONCENTRIC
                | 
                |     For line and axis, legal values are :
                | 
                |         1 : solid
                |         2 : dotted
                |         3 : dashed
                |         4 : dot-dashed
                |         5 : phantom
                | 
                |     Call < to see the changes applied.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         iType
                |             Long.Depends on the DNBTCPTraceReps. Input parameter.
                |             
                | 
                |     Returns:
                |         HRESULT Returns S_OK if it succeeds, otherwise E_FAIL.

        :param int i_rep: enum dnbtcp_trace_reps
        :param int i_type:
        :rtype: None
        """
        return self.tcp_trace.SetType(i_rep, i_type)

    def set_visibility(self, i_rep: int, ib_visible: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisibility(DNBTCPTraceReps iRep,
                | boolean ibVisible)
                | 
                |     Set the TCP trace component (DNBTCPTraceReps) visible (True) or
                |     hidden(False). Call < to see the changes applied.
                | 
                |     Parameters:
                | 
                |         iRep
                |             DNBTCPTraceReps. Define the graphical object the method will be
                |             applied on. Input parameter. 
                |         ibActiv
                |             Boolean. True for visible and False for hidden. Input parameter.

        :param int i_rep: enum dnbtcp_trace_reps
        :param bool ib_visible:
        :rtype: None
        """
        return self.tcp_trace.SetVisibility(i_rep, ib_visible)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_visibility'
        # # vba_code = """
        # # Public Function set_visibility(tcp_trace)
        # #     Dim iRep (2)
        # #     tcp_trace.SetVisibility iRep
        # #     set_visibility = iRep
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TCPTrace(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DrawingDimExtLine(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingDimExtLine
                | 
                | Manages extension lines of a dimension in drawing view.
                | 
                | This interface is obtained from DrawingDimension.GetExtLine
                | method.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_dim_ext_line = com_object

    @property
    def color(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Color() As long
                | 
                |     Returns or sets color of extension line.
                | 
                |     Example:
                |         This example retrieves color of extension line MyExtLine drawing
                |         dimension.
                | 
                |          oColorExtLine = MyExtLine.Color

        :rtype: int
        """

        return self.drawing_dim_ext_line.Color

    @color.setter
    def color(self, value: int):
        """
        :param int value:
        """

        self.drawing_dim_ext_line.Color = value

    @property
    def ext_line_slant(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ExtLineSlant() As double
                | 
                |     Returns or sets slant angle of extension line.
                | 
                |     Example:
                |         This example retrieves slant angle of extension line MyExtLine drawing
                |         dimension.
                | 
                |          oExtLineSlant = MyExtLine.ExtLineSlant

        :rtype: float
        """

        return self.drawing_dim_ext_line.ExtLineSlant

    @ext_line_slant.setter
    def ext_line_slant(self, value: float):
        """
        :param float value:
        """

        self.drawing_dim_ext_line.ExtLineSlant = value

    @property
    def ext_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ExtLineType() As long (Read Only)
                | 
                |     Returns extension line type of dimension.
                | 
                |     Example:
                |         This example retrieves extension line type of dimension MyExtLine
                |         drawing dimension.
                | 
                |          oExtLineType = MyExtLine.ExtLineType

        :rtype: int
        """

        return self.drawing_dim_ext_line.ExtLineType

    @property
    def thickness(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Thickness() As double
                | 
                |     Returns or sets thickness of extension line.
                | 
                |     Example:
                |         This example retrieves thickness of extension line MyExtLine drawing
                |         dimension.
                | 
                |          oThickExtLine = MyExtLine.Thickness

        :rtype: float
        """

        return self.drawing_dim_ext_line.Thickness

    @thickness.setter
    def thickness(self, value: float):
        """
        :param float value:
        """

        self.drawing_dim_ext_line.Thickness = value

    def add_interrupt(self, i_index: int, i_two_points: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub AddInterrupt(long iIndex,
                | CATSafeArrayVariant iTwoPoints)
                | 
                |     Add an interrupt to an extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         iTwoPoints
                |             Defines the first and second point of the gap to create.
                |             
                |         Example:
                |             This example adds an interrupt to MyExtLine path.
                | 
                |              MyExtLine.AddInterrupt(iIndex, iTwoPoints)

        :param int i_index:
        :param tuple i_two_points:
        :rtype: None
        """
        return self.drawing_dim_ext_line.AddInterrupt(i_index, i_two_points)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_interrupt'
        # # vba_code = """
        # # Public Function add_interrupt(drawing_dim_ext_line)
        # #     Dim iIndex (2)
        # #     drawing_dim_ext_line.AddInterrupt iIndex
        # #     add_interrupt = iIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_funnel(self, i_index: int, o_mode: int, o_angle: float, o_height: float, o_width: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetFunnel(long iIndex,
                | long oMode,
                | double oAngle,
                | double oHeight,
                | double oWidth)
                | 
                |     Get funnel information of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oMode
                |             funnel inside/outside mode. 
                |         oAngle
                |             funnel angle. 
                |         oHeight
                |             funnel height. 
                |         oWidth
                |             funnel width. 
                |         Example:
                |             This example gets funnel information of MyExtLine
                |             path.
                | 
                |              MyExtLine.GetFunnel(iIndex, oMode, oAngle, oHeight,
                |              oWidth)

        :param int i_index:
        :param int o_mode:
        :param float o_angle:
        :param float o_height:
        :param float o_width:
        :rtype: None
        """
        return self.drawing_dim_ext_line.GetFunnel(i_index, o_mode, o_angle, o_height, o_width)

    def get_gap(self, i_index: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetGap(long iIndex) As double
                | 
                |     Get gap of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oGap
                |             Gap. 
                |         Example:
                |             This example gets gap of MyExtLine path.
                | 
                |              Gap = MyExtLine.GetGap(iIndex)

        :param int i_index:
        :rtype: float
        """
        return self.drawing_dim_ext_line.GetGap(i_index)

    def get_geom_info(self, i_index: int, o_geom_infos: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetGeomInfo(long iIndex,
                | CATSafeArrayVariant oGeomInfos)
                | 
                |     Get geometrical information of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oGeomInfos
                |             List of geometric coordinates (X1,Y1,X2,Y2,X3,Y3).
                |             
                |         Example:
                |             This example gets geometrical information of MyExtLine
                |             path.
                | 
                |              MyExtLine.GetGeomInfo(iIndex, oGeomInfos)

        :param int i_index:
        :param tuple o_geom_infos:
        :rtype: None
        """
        return self.drawing_dim_ext_line.GetGeomInfo(i_index, o_geom_infos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_geom_info'
        # # vba_code = """
        # # Public Function get_geom_info(drawing_dim_ext_line)
        # #     Dim iIndex (2)
        # #     drawing_dim_ext_line.GetGeomInfo iIndex
        # #     get_geom_info = iIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_interrupt(self, i_index: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetInterrupt(long iIndex) As long
                | 
                |     Get the number of interruptions stored in each extension
                |     lines.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oNbIntOnExtLine
                |             The number of interruptions. 
                |         Example:
                |             This example gets the number of interruptions of MyExtLine
                |             path.
                | 
                |              NbIntOnExtLine = MyExtLine.GetInterrupt(iIndex)

        :param int i_index:
        :rtype: int
        """
        return self.drawing_dim_ext_line.GetInterrupt(i_index)

    def get_overrun(self, i_index: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetOverrun(long iIndex) As double
                | 
                |     Get overrun of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oOverrun
                |             Overrun 
                |         Example:
                |             This example gets overrun of MyExtLine path.
                | 
                |              Overrun = MyExtLine.GetOverrun(iIndex)

        :param int i_index:
        :rtype: float
        """
        return self.drawing_dim_ext_line.GetOverrun(i_index)

    def get_visibility(self, i_index: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetVisibility(long iIndex) As long
                | 
                |     Get visibility of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         oGap
                |             Gap. 
                |         Example:
                |             This example gets visibility of MyExtLine path.
                | 
                |              ExtlineVisibility = MyExtLine.GetVisibility(iIndex)

        :param int i_index:
        :rtype: int
        """
        return self.drawing_dim_ext_line.GetVisibility(i_index)

    def remove_interrupt(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveInterrupt(long iIndex)
                | 
                |     Remove interruption on extension lines.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         Example:
                |             This example Remove interruption on MyExtLine
                |             path.
                | 
                |              MyExtLine.RemoveInterrupt(iIndex)

        :param int i_index:
        :rtype: None
        """
        return self.drawing_dim_ext_line.RemoveInterrupt(i_index)

    def set_funnel(self, i_index: int, i_mode: int, i_angle: float, i_height: float, i_width: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetFunnel(long iIndex,
                | long iMode,
                | double iAngle,
                | double iHeight,
                | double iWidth)
                | 
                |     Set funnel information of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         iMode
                |             funnel inside/outside mode. 
                |         iAngle
                |             funnel angle. 
                |         iHeight
                |             funnel height. 
                |         iWidth
                |             funnel width. 
                |         Example:
                |             This example sets funnel information of MyExtLine
                |             path.
                | 
                |              MyExtLine.SetFunnel(iIndex, iMode, iAngle, iHeight,
                |              iWidth)

        :param int i_index:
        :param int i_mode:
        :param float i_angle:
        :param float i_height:
        :param float i_width:
        :rtype: None
        """
        return self.drawing_dim_ext_line.SetFunnel(i_index, i_mode, i_angle, i_height, i_width)

    def set_gap(self, i_index: int, i_gap: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetGap(long iIndex,
                | double iGap)
                | 
                |     Set gap of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         iGap
                |             gap 
                |         Example:
                |             This example sets gap of MyExtLine path.
                | 
                |              MyExtLine.SetGap(iIndex, iGap)

        :param int i_index:
        :param float i_gap:
        :rtype: None
        """
        return self.drawing_dim_ext_line.SetGap(i_index, i_gap)

    def set_overrun(self, i_index: int, i_overrun: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetOverrun(long iIndex,
                | double iOverrun)
                | 
                |     Set overrun of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         iOverrun
                |             Overrun 
                |         Example:
                |             This example sets overrun of MyExtLine path.
                | 
                |              MyExtLine.SetOverrun(iIndex, iOverrun)

        :param int i_index:
        :param float i_overrun:
        :rtype: None
        """
        return self.drawing_dim_ext_line.SetOverrun(i_index, i_overrun)

    def set_visibility(self, i_index: int, i_extline_visibility: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetVisibility(long iIndex,
                | long iExtlineVisibility)
                | 
                |     Set visibility of dimension extension line.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             1: first extension line 2: second extension line 
                |         iExtlineVisibility
                |             visibility
                |         Example:
                |             This example sets visibility of MyExtLine path.
                | 
                |              MyExtLine.SetVisibility(iIndex,
                |              iExtlineVisibility)

        :param int i_index:
        :param int i_extline_visibility:
        :rtype: None
        """
        return self.drawing_dim_ext_line.SetVisibility(i_index, i_extline_visibility)

    def __repr__(self):
        return f'DrawingDimExtLine(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.human_task import HumanTask
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity


class HumanCallTask(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             HumanCallTask
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIAHumanCallTaskActivity are
                | ...
                | 
                | Do not use the DNBIAHumanCallTaskActivity interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_call_task = com_object

    @property
    def called_task(self) -> HumanTask:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CalledTask() As HumanTask (Read Only)
                | 
                |     Gets the Called Task
                | 
                |     Parameters:
                | 
                |         oHumanTask
                | 
                |     Returns:
                |         Error code of function.

        :rtype: HumanTask
        """

        return HumanTask(self.human_call_task.CalledTask)

    def set_called_task(self, i_target_task: HumanTask) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCalledTask(HumanTask iTargetTask)
                | 
                |     Set the called task
                | 
                |     Parameters:
                | 
                |         iTargetTask
                | 
                |     Returns:
                |         E_FAIL : If the Desired Task belongs to different Manikin or there is Cyclic

        :param HumanTask i_target_task:
        :rtype: None
        """
        return self.human_call_task.SetCalledTask(i_target_task.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_called_task'
        # # vba_code = """
        # # Public Function set_called_task(human_call_task)
        # #     Dim iTargetTask (2)
        # #     human_call_task.SetCalledTask iTargetTask
        # #     set_called_task = iTargetTask
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HumanCallTask(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty


class ABQSmoothStepAmplitude(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQSmoothStepAmplitude
                | 
                | Represents a smooth step amplitude (ABQSmoothStepAmplitude)
                | object.
                | Role: Access an Abaqus smooth step amplitude or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_smooth_step_amplitude = com_object

    @property
    def time_amplitude_table_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeAmplitudeTableSize() As long (Read Only)
                | 
                |     Returns the size of the time/amplitude table.
                | 
                |     Returns:
                |         The size of the time/amplitude table.

        :rtype: int
        """

        return self.abq_smooth_step_amplitude.TimeAmplitudeTableSize

    @property
    def time_span(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeSpan() As TimeSpan_Type
                | 
                |     Sets or returns the timespan in smooth step amplitude.
                | 
                |     Returns:
                |         The timespan
                | 
                |         Legal values:
                | 
                |         STEP_TIME
                |         TOTAL_TIME

        :rtype: int
        """

        return self.abq_smooth_step_amplitude.TimeSpan

    @time_span.setter
    def time_span(self, value: int):
        """
        :param int value:
        """

        self.abq_smooth_step_amplitude.TimeSpan = value

    def add_time_amplitude_table(self, i_time: tuple, i_amplitude: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddTimeAmplitudeTable(CATSafeArrayVariant iTime,
                | CATSafeArrayVariant iAmplitude)
                | 
                |     Adds a list of time and amplitude for the specified time span STEP_TIME or
                |     TOTAL_TIME The number of values in both of the parameters must match. If either
                |     list contains extra values, the extra values are
                |     discarded.
                | 
                |     Parameters:
                | 
                |         iTime
                |             The list of times.
                |         iAmplitude
                |             The list of amplitudes.

        :param tuple i_time:
        :param tuple i_amplitude:
        :rtype: None
        """
        return self.abq_smooth_step_amplitude.AddTimeAmplitudeTable(i_time, i_amplitude)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_time_amplitude_table'
        # # vba_code = """
        # # Public Function add_time_amplitude_table(abq_smooth_step_amplitude)
        # #     Dim iTime (2)
        # #     abq_smooth_step_amplitude.AddTimeAmplitudeTable iTime
        # #     add_time_amplitude_table = iTime
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_time_amplitude_table(self, o_time: tuple, o_amplitude: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTimeAmplitudeTable(CATSafeArrayVariant oTime,
                | CATSafeArrayVariant oAmplitude)
                | 
                |     Returns a list of time and amplitude for the specified timespan (STEP_TIME
                |     or TOTAL_TIME).
                | 
                |     Parameters:
                | 
                |         oTime
                |             The list of times.
                |         oTemperature
                |             The list of amplitudes.

        :param tuple o_time:
        :param tuple o_amplitude:
        :rtype: None
        """
        return self.abq_smooth_step_amplitude.GetTimeAmplitudeTable(o_time, o_amplitude)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_time_amplitude_table'
        # # vba_code = """
        # # Public Function get_time_amplitude_table(abq_smooth_step_amplitude)
        # #     Dim oTime (2)
        # #     abq_smooth_step_amplitude.GetTimeAmplitudeTable oTime
        # #     get_time_amplitude_table = oTime
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSmoothStepAmplitude(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SWKErgoRULA(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKErgoRULA
                | 
                | This interface deals the RULA ergonomic analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_ergo_rula = com_object

    @property
    def arm_abducted(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArmAbducted() As boolean (Read Only)
                | 
                |     This property is True if the arm of the manikin is abducted, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.ArmAbducted

    @property
    def arm_out_to_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArmOutToSide() As boolean (Read Only)
                | 
                |     This property is True if the arm of the manikin is out to the side, given
                |     the manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.ArmOutToSide

    @property
    def neck_side_bending(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NeckSideBending() As boolean (Read Only)
                | 
                |     This property is True if the neck of the manikin is bent, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.NeckSideBending

    @property
    def neck_twisted(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NeckTwisted() As boolean (Read Only)
                | 
                |     This property is True if the neck of the manikin is twisted, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.NeckTwisted

    @property
    def object_weight(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ObjectWeight() As CATBSTR
                | 
                |     Returns or sets the weight of the object being carried.

        :rtype: str
        """

        return self.swk_ergo_rula.ObjectWeight

    @object_weight.setter
    def object_weight(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_rula.ObjectWeight = value

    @property
    def overall_score(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OverallScore() As long (Read Only)
                | 
                |     This field is the overall RULA score, given the manikin's current posture.

        :rtype: int
        """

        return self.swk_ergo_rula.OverallScore

    @property
    def shoulder_raised(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShoulderRaised() As boolean (Read Only)
                | 
                |     This property is True if the shoulder of the manikin is raised, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.ShoulderRaised

    @property
    def trunk_side_bending(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TrunkSideBending() As boolean (Read Only)
                | 
                |     This property is True if the trunk of the manikin is bent, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.TrunkSideBending

    @property
    def trunk_twisted(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TrunkTwisted() As boolean (Read Only)
                | 
                |     This property is True if the trunk of the manikin is twisted, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.TrunkTwisted

    @property
    def verdict(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Verdict() As CATBSTR (Read Only)
                | 
                |     This field gives a text string which represents the interpretaton of the
                |     overall RULA score.

        :rtype: str
        """

        return self.swk_ergo_rula.Verdict

    @property
    def wrist_bent(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WristBent() As boolean (Read Only)
                | 
                |     This property is True if the wrist of the manikin is bent, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.WristBent

    @property
    def wrist_twisted(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WristTwisted() As boolean (Read Only)
                | 
                |     This property is True if the wrist of the manikin is twisted, given the
                |     manikin's current posture.

        :rtype: bool
        """

        return self.swk_ergo_rula.WristTwisted

    def __repr__(self):
        return f'SWKErgoRula(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.list import List
from pycatia.knowledge_interfaces.parameter import Parameter


class ListParameter(Parameter):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.Parameter
                |                         ListParameter
                | 
                | Represents a CATIAListParameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.list_parameter = com_object

    @property
    def value_list(self) -> List:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueList() As List (Read Only)
                | 
                |     Returns or sets the value of the List object.

        :rtype: List
        """

        return List(self.list_parameter.ValueList)

    def __repr__(self):
        return f'ListParameter(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_mesh_part import AnalysisMeshPart
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnalysisMeshParts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnalysisMeshParts
                | 
                | The collection of analysis meshparts.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnalysisMeshPart)
        self.analysis_mesh_parts = com_object

    def add(self, i_type: str) -> AnalysisMeshPart:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iType) As AnalysisMeshPart
                | 
                |     Creates a new meshpart and adds it to the meshpart
                |     collection.
                |     The meshpart will be created linked to the AnalysisMeshManager
                |     object.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of mesh part to create. 
                | 
                |     Returns:
                |         The created meshpart

        :param str i_type:
        :rtype: AnalysisMeshPart
        """
        return AnalysisMeshPart(self.analysis_mesh_parts.Add(i_type))

    def item(self, i_index: cat_variant) -> AnalysisMeshPart:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As AnalysisMeshPart
                | 
                |     Returns a meshpart using its index or its name from the meshpart
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the meshpart to retrieve from the
                |             collection of meshparts. As a numeric, this index is the rank of the meshpart
                |             in the collection. The index of the first meshpart in the collection is 1, and
                |             the index of the last meshpart is Count. As a string, it is the name you
                |             assigned to the meshpart using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved meshpart.

        :param cat_variant i_index:
        :rtype: AnalysisMeshPart
        """
        return AnalysisMeshPart(self.analysis_mesh_parts.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a meshpart using its index or its name from the meshpart
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the meshpart to retrieve from the
                |             collection of meshpart. As a numeric, this index is the rank of the meshpart in
                |             the collection. The index of the first meshpart in the collection is 1, and the
                |             index of the last meshpart is Count. As a string, it is the name you assigned
                |             to the meshpart using the 
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.analysis_mesh_parts.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(analysis_mesh_parts)
        # #     Dim iIndex (2)
        # #     analysis_mesh_parts.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisMeshParts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.constraints import Constraints
from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
from pycatia.sketcher_interfaces.axis_2D import Axis2D
from pycatia.sketcher_interfaces.factory_2D import Factory2D
from pycatia.sketcher_interfaces.line_2D import Line2D
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Sketch(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Sketch
                | 
                | The Sketch is a 2D based element comprising constrained 2D geometrical
                | elements.
                | The Sketch is created by giving a 2D support.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sketch = com_object

    @property
    def absolute_axis(self) -> Axis2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AbsoluteAxis() As Axis2D (Read Only)
                | 
                |     Returns the 2D absolute axis of the sketch. The absolute axis is used for
                |     constraining the sketch in 3D space, and its constituting horizontal and
                |     vertical directions can also be used to constrain horizontally or vertically
                |     subsequent geometrical elements in the sketch.
                | 
                |     Returns:
                |         oAxis The absolute axis of the sketch (@see CATIAAxis2D for more
                |         information).
                | 
                |         Example:
                |             The following example places in myAxis the absolute
                |             axis
                |             of the sketch mySketch:
                | 
                |              Set myAxis = mySketch.AbsoluteAxis

        :rtype: Axis2D
        """

        return Axis2D(self.sketch.AbsoluteAxis)

    @property
    def center_line(self) -> Line2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterLine() As Line2D
                | 
                |     Returns the geometric 2D line defined as the center line of the sketch.
                |     Center lines are then used for creating shafts.
                | 
                |     Returns:
                |         oLine The center line of the sketch(@see CATIALine2D for more
                |         information).
                | 
                |         Example:
                |             The following example returns in myCenterLine the center
                |             line
                |             in the sketch mySketch:
                | 
                |              Set myCenterLine = mySketch.CenterLine

        :rtype: Line2D
        """

        return Line2D(self.sketch.CenterLine)

    @center_line.setter
    def center_line(self, value: Line2D):
        """
        :param Line2D value:
        """

        self.sketch.CenterLine = value

    @property
    def constraints(self) -> Constraints:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Constraints() As Constraints (Read Only)
                | 
                |     Returns the list of constraints included in the sketch.
                | 
                |     Returns:
                |         oConstraints The list of constraints in the sketch (@see
                |         CATIAConstraints
                |         for more information).
                | 
                |         Example:
                |             The following example returns in colConstraint the list of
                |             constraints
                |             in the sketch mySketch:
                | 
                |              Set colConstraint = mySketch.Constraints

        :rtype: Constraints
        """

        return Constraints(self.sketch.Constraints)

    @property
    def factory_2d(self) -> Factory2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Factory2D() As Factory2D (Read Only)
                | 
                |     Returns the 2D factory of the sketch. Take care that you must open
                |     edition
                |     on a sketch before adding or modifying elements in it.
                | 
                |     Returns:
                |         oFactory The 2D geometrical factory of the sketch (@see
                |         CATIAFactory2D
                |         for more information).
                | 
                |         Example:
                |             The following example returns in my2DFactory the 2D
                |             factory
                |             of the sketch mySketch:
                | 
                |              Set my2DFactory = mySketch.Factory2D

        :rtype: Factory2D
        """

        return Factory2D(self.sketch.Factory2D)

    @property
    def geometric_elements(self) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property GeometricElements() As GeometricElements (Read
                | Only)
                | 
                |     Returns the list of geometrical elements included in the
                |     sketch.
                | 
                |     Returns:
                |         oGeometricElements The list of geometric elements in the sketch (@see
                |         CATIAGeometricElements
                |         for more information).
                | 
                |         Example:
                |             The following example returns in colGeometry the list of
                |             geometrical
                |             elements in the sketch mySketch:
                | 
                |              Set colGeometry = mySketch.GeometricElements

        :rtype: GeometricElements
        """

        return GeometricElements(self.sketch.GeometricElements)

    def close_edition(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CloseEdition()
                | 
                |     Closes the Sketch Edition. Once you have finished working with the sketch,
                |     you
                |     must close its edition before using it for sketch-based
                |     shapes.
                | 
                |     Example:
                |         The following example closes the edition of the sketch
                |         mySketch:
                | 
                |          mySketch.CloseEdition

        :rtype: None
        """
        return self.sketch.CloseEdition()

    def evaluate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Evaluate()
                | 
                |     Evaluate the constraint system of the sketch

        :rtype: None
        """
        return self.sketch.Evaluate()

    def get_absolute_axis_data(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetAbsoluteAxisData(CATSafeArrayVariant oAxisData)
                | 
                |     Returns the sketch axis coordinates in 3D space. The matrix returned
                |     comprises 9 doubles, the first 3 being the coordinates
                |     of the axis origin, the next 3 being those of the horizontal axis, and
                |     the
                |     last 3 those of the vertical axis.
                |     The sketch horizontal axis is in fact computed from the first non null
                |     projection of one of the 3 3D space axes on the sketch
                |     plane.
                | 
                |     Returns:
                |         oAxisData The matrix of the axis in 3D space.
                | 
                |         Example:
                |             The following example reads the coordinates of the
                |             axis
                |             of the sketch mySketch:
                | 
                |              Dim myAxisCoordinate (8)
                |              mySketch.GetAbsoluteAxisData myAxisCoordinate
                |              Set OriginX = myAxisCoordinate(1)
                |              Set OriginY = myAxisCoordinate(2)
                |              Set OriginZ = myAxisCoordinate(3)
                |              Set HorizontalX = myAxisCoordinate(4)
                |              Set HorizontalY = myAxisCoordinate(5)
                |              Set HorizontalZ = myAxisCoordinate(6)
                |              Set VerticalX = myAxisCoordinate(7)
                |              Set VerticalY = myAxisCoordinate(8)
                |              Set VerticalZ = myAxisCoordinate(9)

        :rtype: tuple
        """

        vba_function_name = 'get_absolute_axis_data'
        vba_code = """
        Public Function get_absolute_axis_data(sketch)
            Dim oAxisData(8)
            sketch.GetAbsoluteAxisData oAxisData
            get_absolute_axis_data = oAxisData
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def inverse_orientation(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InverseOrientation()
                | 
                |     Inverse Orientation Of Sketch

        :rtype: None
        """
        return self.sketch.InverseOrientation()

    def open_edition(self) -> Factory2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func OpenEdition() As Factory2D
                | 
                |     Opens the Sketch Edition. You must open edition on a sketch before you can
                |     add
                |     elements in it. The CATIAFactory2D returned then enables you to create
                |     2D
                |     geometrical elements in the sketch.
                | 
                |     Returns:
                |         oFactory Returns the 2D FACTORY.
                | 
                |         Example:
                |             The following example opens edition on the sketch
                |             mySketch
                |             and places the factory in my2DFactory:
                | 
                |              Set my2DFactory = mySketch.OpenEdition

        :rtype: Factory2D
        """
        return Factory2D(self.sketch.OpenEdition())

    def set_absolute_axis_data(self, i_axis_data: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAbsoluteAxisData(CATSafeArrayVariant iAxisData)
                | 
                |     Sets the absolute axis of the sketch in 3D space.
                | 
                |     Parameters:
                | 
                |         oAxisData
                |             The matrix comprises 9 doubles, the first 3 being the
                |             coordinates
                |             of the axis origin, the next 3 being those of the horizontal
                |             axis,
                |             and the last 3 those of the vertical axis of the absolute
                |             axis.

        :param tuple i_axis_data:
        :rtype: None
        """
        return self.sketch.SetAbsoluteAxisData(i_axis_data)

    def __repr__(self):
        return f'Sketch(name="{self.name}")'
